@@ -7,22 +7,22 @@
  * Contract with IBM Corp.
  *******************************************************************************/
 /* Copyright (c) 2020 Red Hat, Inc. */
+/* Copyright Contributors to the Open Cluster Management project */
+
 'use strict'
 
 import { updateModal } from '../../actions/common'
+import config from '../../../server/lib/shared/config'
 import _ from 'lodash'
 
-export const resourceActions = (action, dispatch, resourceType, data) => {
+export const resourceActions = (action, dispatch, resourceType, data, history) => {
   switch (action) {
+  case 'table.actions.policy.details': {
+    return history.push(`${config.contextPath}/all/${data.namespace}/${data.name}`)
+  }
+  case 'table.actions.policy.edit':
   case 'table.actions.edit': {
-    return dispatch(updateModal(
-      { open: true, type: 'resource-edit', action: 'put', resourceType, editorMode: 'json',
-        label: {
-          primaryBtn: 'modal.button.submit',
-          label: `modal.edit-${resourceType.name.toLowerCase()}.label`,
-          heading: `modal.edit-${resourceType.name.toLowerCase()}.heading`
-        },
-        data: { kind: resourceType.name, ...data }}))
+    return history.push(`${config.contextPath}/all/${data.namespace}/${data.name}/edit`)
   }
   case 'table.actions.launch.cluster':{
     const consoleURL = _.get(data, 'consoleURL')
@@ -31,33 +31,45 @@ export const resourceActions = (action, dispatch, resourceType, data) => {
     }
     return
   }
+  case 'table.actions.automation': {
+    return dispatch(updateModal(
+      { open: true, type: 'resource-automation', resourceType,
+        label: {
+          primaryBtn: `modal.automation-${resourceType.name.toLowerCase()}.primaryBtn`,
+          label: `modal.automation-${resourceType.name.toLowerCase()}.label`,
+          heading: `modal.automation-${resourceType.name.toLowerCase()}.heading`
+        },
+        data: { apiVersion: resourceType.api_version, kind: resourceType.name, ...data }}))
+  }
   case 'table.actions.compliance.remove':
   case 'table.actions.policy.remove':
   case 'table.actions.remove': {
     return dispatch(updateModal(
       { open: true, type: 'resource-remove', resourceType,
         label: {
-          primaryBtn: `modal.remove-${resourceType.name.toLowerCase()}.heading`,
+          primaryBtn: `modal.remove-${resourceType.name.toLowerCase()}.primaryBtn`,
           label: `modal.remove-${resourceType.name.toLowerCase()}.label`,
           heading: `modal.remove-${resourceType.name.toLowerCase()}.heading`
         },
         data: { apiVersion: resourceType.api_version, kind: resourceType.name, ...data }}))
   }
+  case 'table.actions.policy.disable':
   case 'table.actions.disable': {
     return dispatch(updateModal(
       { open: true, type: 'resource-disable', resourceType,
         label: {
-          primaryBtn: `modal.disable-${resourceType.name.toLowerCase()}.heading`,
+          primaryBtn: `modal.disable-${resourceType.name.toLowerCase()}.primaryBtn`,
           label: `modal.disable-${resourceType.name.toLowerCase()}.label`,
           heading: `modal.disable-${resourceType.name.toLowerCase()}.heading`
         },
         data: { apiVersion: resourceType.api_version, kind: resourceType.name, ...data }}))
   }
+  case 'table.actions.policy.enable':
   case 'table.actions.enable': {
     return dispatch(updateModal(
       { open: true, type: 'resource-enable', resourceType,
         label: {
-          primaryBtn: `modal.enable-${resourceType.name.toLowerCase()}.heading`,
+          primaryBtn: `modal.enable-${resourceType.name.toLowerCase()}.primaryBtn`,
           label: `modal.enable-${resourceType.name.toLowerCase()}.label`,
           heading: `modal.enable-${resourceType.name.toLowerCase()}.heading`
         },
@@ -67,7 +79,7 @@ export const resourceActions = (action, dispatch, resourceType, data) => {
     return dispatch(updateModal(
       { open: true, type: 'resource-enforce', resourceType,
         label: {
-          primaryBtn: `modal.enforce-${resourceType.name.toLowerCase()}.heading`,
+          primaryBtn: `modal.enforce-${resourceType.name.toLowerCase()}.primaryBtn`,
           label: `modal.enforce-${resourceType.name.toLowerCase()}.label`,
           heading: `modal.enforce-${resourceType.name.toLowerCase()}.heading`
         },
@@ -77,12 +89,13 @@ export const resourceActions = (action, dispatch, resourceType, data) => {
     return dispatch(updateModal(
       { open: true, type: 'resource-inform', resourceType,
         label: {
-          primaryBtn: `modal.inform-${resourceType.name.toLowerCase()}.heading`,
+          primaryBtn: `modal.inform-${resourceType.name.toLowerCase()}.primaryBtn`,
           label: `modal.inform-${resourceType.name.toLowerCase()}.label`,
           heading: `modal.inform-${resourceType.name.toLowerCase()}.heading`
         },
         data: { apiVersion: resourceType.api_version, kind: resourceType.name, ...data }}))
   }
+  case 'table.actions.automation.edit':
   default:
     return undefined
   }
