@@ -7,18 +7,21 @@
  * Contract with IBM Corp.
  *******************************************************************************/
 /* Copyright (c) 2020 Red Hat, Inc. */
+/* Copyright Contributors to the Open Cluster Management project */
+
 
 import React from 'react'
 import { Tooltip } from '@patternfly/react-core'
 import PropTypes from 'prop-types'
-import truncate from '../../util/truncate-middle'
+import truncate from '../../utils/truncate-middle'
 
 class TruncateText extends React.PureComponent {
   static propTypes = {
     maxCharacters: PropTypes.number,
-    maxWidth: PropTypes.number,
+    maxWidth: PropTypes.string,
+    noTooltip: PropTypes.bool,
     position: PropTypes.string,
-    text: PropTypes.string.isRequired,
+    text: PropTypes.oneOfType([PropTypes.array, PropTypes.string]).isRequired,
     textEnd: PropTypes.string
   }
 
@@ -27,7 +30,7 @@ class TruncateText extends React.PureComponent {
   }
 
   render() {
-    const {text, maxCharacters, maxWidth, position, textEnd} = this.props
+    const {text, maxCharacters, maxWidth, noTooltip, position, textEnd} = this.props
     const postfix = textEnd ? textEnd : ''
     if (!text) {
       return ''
@@ -37,16 +40,24 @@ class TruncateText extends React.PureComponent {
     }
     else if (text.length <= maxCharacters){
       return `${text}${postfix}`
+    } else {
+      if (noTooltip) {
+        return <span className='textWithTruncation'>
+          {`${truncate(text, maxCharacters)}${postfix}`}
+        </span>
+      } else {
+        return <Tooltip
+          maxWidth = {maxWidth ? maxWidth : '80rem'}
+          enableFlip = {false}
+          position = {position ? position : 'top'}
+          content = {<div>{text}</div>}
+          >
+            <span className='textWithTruncation'>
+              {`${truncate(text, maxCharacters)}${postfix}`}
+            </span>
+        </Tooltip>
+      }
     }
-
-    return <Tooltip
-      maxWidth = {maxWidth ? maxWidth : '80rem'}
-      enableFlip = {false}
-      position = {position ? position : 'top'}
-      content = {<div>{text}</div>}
-    >
-      <span className='textWithTruncation'>{`${truncate(text, maxCharacters)}${postfix}`}</span>
-    </Tooltip>
   }
 }
 
