@@ -17,7 +17,7 @@ import PropTypes from 'prop-types'
 import _ from 'lodash'
 import { Alert } from '@patternfly/react-core'
 import msgs from '../../nls/platform.properties'
-import { AcmDescriptionList, AcmTable } from '@open-cluster-management/ui-components'
+import { AcmDescriptionList, AcmTable } from '@stolostron/ui-components'
 import NoResource from '../../components/common/NoResource'
 import policyDetailsClusterListDef from '../../tableDefinitions/policyDetailsClusterListDef'
 import policyDetailsOverviewDef from '../../tableDefinitions/policyDetailsOverviewDef'
