@@ -7,6 +7,8 @@
  * Contract with IBM Corp.
  *******************************************************************************/
 /* Copyright (c) 2020 Red Hat, Inc. */
+/* Copyright Contributors to the Open Cluster Management project */
+
 /*
  *
  * Things you should never do inside a reducer:
@@ -22,10 +24,9 @@
  */
 
 import { createResourceReducer, resourceReducerFunction } from './common'
-import { RESOURCE_TYPES } from '../../lib/shared/constants'
+import { RESOURCE_TYPES } from '../utils/constants'
 import _ from 'lodash'
 
-export { user, loggedIn } from './user'
 export { userAccess } from './access'
 export { resourceToolbar } from './common'
 export { secondaryHeader } from './common'
@@ -36,6 +37,7 @@ export const ALL_POLICIES = createResourceReducer(resourceReducerFunction, predi
 export const PoliciesList = createResourceReducer(resourceReducerFunction, predicate.bind(null, RESOURCE_TYPES.POLICY))
 export const PlacementBindingsList = createResourceReducer(resourceReducerFunction, predicate.bind(null, RESOURCE_TYPES.PLACEMENT_BINDING))
 export const PlacementRulesList = createResourceReducer(resourceReducerFunction, predicate.bind(null, RESOURCE_TYPES.PLACEMENT_RULE))
+export const AnsibleJob = createResourceReducer(resourceReducerFunction, predicate.bind(null, RESOURCE_TYPES.ANSIBLE_JOB))
 
 export { resourceFilters } from './filter'
 
