@@ -1,4 +1,6 @@
 /* Copyright (c) 2020 Red Hat, Inc. */
+/* Copyright Contributors to the Open Cluster Management project */
+
 
 'use strict'
 
@@ -10,7 +12,6 @@ import {
 import {
   breakWord,
   wrappable,
-  sortable
 } from '@patternfly/react-table'
 
 export default {
@@ -19,32 +20,51 @@ export default {
   ],
   tableKeys: [
     {
+      label: 'cluster',
       msgKey: 'table.header.cluster.name',
       resourceKey: 'cluster',
-      transforms: [wrappable, sortable],
+      searchable: true,
+      sortable: true,
+      sortLabel: 'cluster.rawData',
+      transforms: [wrappable],
       cellTransforms: [breakWord],
       transformFunction: buildClusterLink,
     },
     {
+      label: 'namespace',
       msgKey: 'table.header.cluster.namespace',
       resourceKey: 'namespace',
-      transforms: [wrappable, sortable],
+      searchable: true,
+      sortable: true,
+      transforms: [wrappable],
       cellTransforms: [breakWord],
     },
     {
+      label: 'clusterCompliant',
       msgKey: 'table.header.cluster.violation',
       resourceKey: 'clusterCompliant',
-      transforms: [wrappable, sortable],
+      searchable: true,
+      sortable: true,
+      sortLabel: 'clusterCompliant.rawData',
+      transforms: [wrappable],
       cellTransforms: [breakWord],
-      transformFunction: getClusterCompliantStatus
+      transformFunction: getClusterCompliantStatus,
     },
     {
+      label: 'nonCompliant',
       msgKey: 'table.header.violated',
+      searchable: true,
       resourceKey: 'nonCompliant',
-      transforms: [wrappable, sortable],
+      transforms: [wrappable],
       cellTransforms: [breakWord],
       transformFunction: getClusterViolationLabels,
     },
+    // Row metadata
+    {
+      hidden: true,
+      label: 'consoleURL',
+      resourceKey: 'consoleURL',
+    }
   ],
   sortBy: {
     index: 2,
