@@ -1,52 +1,71 @@
 /* Copyright (c) 2020 Red Hat, Inc. */
+/* Copyright Contributors to the Open Cluster Management project */
+
 'use strict'
 
 import React from 'react'
 import _ from 'lodash'
 import {
   breakWord,
-  sortable,
   wrappable,
 } from '@patternfly/react-table'
 import { buildCompliantCell } from './utils'
-import msgs from '../../nls/platform.properties'
+import msgs from '../nls/platform.properties'
 
 export default {
   tableKeys: [
     {
       msgKey: 'table.header.name',
+      label: 'name',
+      searchable: true,
+      sortable: true,
       resourceKey: 'object.metadata.name',
-      transforms: [sortable, wrappable],
+      transforms: [wrappable],
       cellTransforms: [breakWord],
     },
     {
       msgKey: 'table.header.namespace',
+      label: 'namespace',
+      searchable: true,
+      sortable: true,
       resourceKey: 'object.metadata.namespace',
-      transforms: [sortable, wrappable],
+      transforms: [wrappable],
     },
     {
       msgKey: 'table.header.kind',
+      label: 'kind',
+      searchable: true,
+      sortable: true,
       resourceKey: 'object.kind',
-      transforms: [sortable, wrappable],
+      transforms: [wrappable],
     },
     {
       msgKey: 'table.header.apiGroups',
+      label: 'apiGroups',
+      sortable: true,
       resourceKey: 'object.apiVersion',
-      transforms: [sortable, wrappable],
+      transforms: [wrappable],
       cellTransforms: [breakWord],
     },
     {
       msgKey: 'table.header.compliant',
+      label: 'compliant',
+      sortable: true,
+      sortLabel: 'compliant.rawData',
       resourceKey: 'compliant',
-      transforms: [sortable, wrappable],
+      transforms: [wrappable],
       transformFunction: buildCompliantCell,
     },
     {
       msgKey: 'table.header.reason',
+      label: 'reason',
+      searchable: true,
+      sortable: true,
       resourceKey: 'reason',
-      transforms: [sortable, wrappable],
+      transforms: [wrappable],
     },
     {
+      label: 'link',
       transformFunction: buildViewYamlLink
     },
   ],
@@ -56,12 +75,16 @@ export default {
   }
 }
 
-function buildViewYamlLink(item, locale) {
+export function buildViewYamlLink(item, locale) {
   const cluster = _.get(item, 'cluster')
   const name = _.get(item, 'object.metadata.name')
   const namespace = _.get(item, 'object.metadata.namespace', '')
   const apiVersion = _.get(item, 'object.apiVersion')
   const kind = _.get(item, 'object.kind')
+  const reason = _.get(item, 'reason')
+  if (reason === 'Resource not found but should exist') {
+    return ''
+  }
   if (cluster && kind && apiVersion && name) {
     if (namespace !== '') {
       return <a target='_blank' rel='noopener noreferrer'
