@@ -1,4 +1,6 @@
 /* Copyright (c) 2020 Red Hat, Inc. */
+/* Copyright Contributors to the Open Cluster Management project */
+
 'use strict'
 
 import React from 'react'
@@ -7,6 +9,7 @@ import {
   GreenCheckCircleIcon,
   RedExclamationCircleIcon,
   YellowExclamationTriangleIcon,
+  GrayOutlinedQuestionCircleIcon,
 } from '../../../../src-web/components/common/Icons'
 import toJson from 'enzyme-to-json'
 
@@ -56,3 +59,18 @@ describe('test component YellowExclamationTriangleIcon', () => {
     expect(toJson(component)).toMatchSnapshot()
   })
 })
+
+describe('test component GrayOutlinedQuestionCircleIcon', () => {
+  it('renders as expected', () => {
+    const component = mount(
+      <GrayOutlinedQuestionCircleIcon tooltip='aaaa' />
+    )
+    expect(toJson(component)).toMatchSnapshot()
+  })
+  it('renders tooltip as expected', () => {
+    const component = mount(
+      <GrayOutlinedQuestionCircleIcon />
+    )
+    expect(toJson(component)).toMatchSnapshot()
+  })
+})
