@@ -7,8 +7,10 @@
  * Contract with IBM Corp.
  *******************************************************************************/
 /* Copyright (c) 2020 Red Hat, Inc. */
+/* Copyright Contributors to the Open Cluster Management project */
+
 const path = require('path')
-const platformFilePath = path.join(__dirname, '../../../nls/platform.properties')
+const platformFilePath = path.join(__dirname, '../../../src-web/nls/platform.properties')
 const propertiesParser = require('properties-parser')
 const jsonfile = require('jsonfile')
 const fs = require('fs')
