@@ -1,4 +1,6 @@
 /* Copyright (c) 2020 Red Hat, Inc. */
+/* Copyright Contributors to the Open Cluster Management project */
+
 'use strict'
 
 // For a given input, a selector should always produce the same output.
@@ -39,4 +41,12 @@ describe('Access reducer', () => {
     }
     expect(userAccess(state, action)).toEqual(expectedValue)
   })
+
+  it('should return undefine', () => {
+    const state = {
+      test: 'test'
+    }
+    const expectedValue = undefined
+    expect(userAccess(state, null)).toEqual(expectedValue)
+  })
 })
