@@ -1,7 +1,9 @@
 /* Copyright (c) 2020 Red Hat, Inc. */
+/* Copyright Contributors to the Open Cluster Management project */
+
 
 import { predicate } from '../../../src-web/reducers/index'
-import { RESOURCE_TYPES } from '../../../lib/shared/constants'
+import { RESOURCE_TYPES } from '../../../src-web/utils/constants'
 
 describe('predicate', () => {
   it('should return true', () => {
