@@ -1,4 +1,4 @@
-var _Object$defineProperty = require("../core-js/object/define-property");
+var _Object$defineProperty = require("@babel/runtime-corejs3/core-js/object/define-property");
 
 function _initializerDefineProperty(target, property, descriptor, context) {
   if (!descriptor) return;
