@@ -66,7 +66,8 @@ module.exports = class Interceptor {
 
     //  We use lower-case header field names throughout Nock.
     this.reqheaders = common.headersFieldNamesToLowerCase(
-      scope.scopeOptions.reqheaders || {}
+      scope.scopeOptions.reqheaders || {},
+      true
     )
     this.badheaders = common.headersFieldsArrayToLowerCase(
       scope.scopeOptions.badheaders || []
@@ -412,6 +413,12 @@ module.exports = class Interceptor {
   }
 
   matchHostName(options) {
+    const { basePath } = this.scope
+
+    if (basePath instanceof RegExp) {
+      return basePath.test(options.hostname)
+    }
+
     return options.hostname === this.scope.urlParts.hostname
   }
 
@@ -442,13 +449,17 @@ module.exports = class Interceptor {
   markConsumed() {
     this.interceptionCounter++
 
-    remove(this)
-
-    if ((this.scope.shouldPersist() || this.counter > 0) && this.filePath) {
+    if (
+      (this.scope.shouldPersist() || this.counter > 0) &&
+      this.interceptionCounter > 1 &&
+      this.filePath
+    ) {
       this.body = fs.createReadStream(this.filePath)
       this.body.pause()
     }
 
+    remove(this)
+
     if (!this.scope.shouldPersist() && this.counter < 1) {
       this.scope.remove(this._key, this)
     }
