@@ -4,6 +4,7 @@
  * Forked from reactabular-table version 8.14.0
  * https://github.com/reactabular/reactabular/tree/v8.14.0/packages/reactabular-table/src
  */
+import * as React from 'react';
 import mergeWith from 'lodash/mergeWith';
 import { css } from '@patternfly/react-styles';
 
@@ -21,6 +22,13 @@ export function mergeProps(...props: any) {
   // Avoid mutating the first prop collection
   return mergeWith(mergeWith({}, firstProps), ...restProps, (a: any, b: any, key: any) => {
     if (key === 'children') {
+      if (a && b) {
+        // compose the two
+        return React.cloneElement(a, {
+          children: b
+        });
+      }
+
       // Children have to be merged in reverse order for Reactabular
       // logic to work.
       return { ...b, ...a };
